# CoreX metrics - datadog

This package provides an implementation of the CoreX metrics interface for datadog.

## Installation
~~~bash
pip install corex-metrics-datadog
~~~

## Usage
~~~python
from corex_metrics_datadog.handler import DatadogHandler
handler = DatadogHandler()
handler.example_method()
~~~

## License
This package is licensed under the MIT License. See [LICENSE](../LICENSE) for details.
